# eric7.Plugins.VcsPlugins.vcsPySvn.SvnUrlSelectionDialog

Module implementing a dialog to enter the URLs for the svn diff command.

### Global Attributes

None

### Classes

SvnUrlSelectionDialog | Class implementing a dialog to enter the URLs for the svn diff command.

### Functions

None

## SvnUrlSelectionDialog

Class implementing a dialog to enter the URLs for the svn diff command.

### Derived from

QDialog, Ui_SvnUrlSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnUrlSelectionDialog | Constructor
__changeLabelCombo | Private method used to change the label combo depending on the selected type.
getURLs | Public method to get the entered URLs.
on_typeCombo1_currentIndexChanged | Private slot called when the selected type was changed.
on_typeCombo2_currentIndexChanged | Private slot called when the selected type was changed.

### Static Methods

None

#### SvnUrlSelectionDialog (Constructor)

SvnUrlSelectionDialog(vcs, tagsList, branchesList, path, parent=None)

Constructor

vcs (Subversion)
  reference to the vcs object
tagsList (list of str)
  list of tags
branchesList (list of str)
  list of branches
path (str)
  pathname to determine the repository URL from
parent (QWidget)
  parent widget of the dialog

#### SvnUrlSelectionDialog.__changeLabelCombo

__changeLabelCombo(labelCombo, type_)

Private method used to change the label combo depending on the selected type.

labelCombo (QComboBox)
  reference to the labelCombo object
type_ (str)
  type string

#### SvnUrlSelectionDialog.getURLs

getURLs()

Public method to get the entered URLs.

Return:
  tuple of list of two URL strings and a flag indicating a diff summary

Return Type:
  tuple of (list of [str, str], bool)

#### SvnUrlSelectionDialog.on_typeCombo1_currentIndexChanged

on_typeCombo1_currentIndexChanged(index)

Private slot called when the selected type was changed.

index (int)
  index of the current item

#### SvnUrlSelectionDialog.on_typeCombo2_currentIndexChanged

on_typeCombo2_currentIndexChanged(index)

Private slot called when the selected type was changed.

index (int)
  index of the current item

Up